/*
 * Ambient - the ultimate desktop
 * ------------------------------
 *  2001-2004 by David Gerber <zapek@morphos.net>
 * All Rights Reserved
 *
 * use 'make rebuild_defaults' to rebuild default.c
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 * $Id: default.c,v 1.3 2006/02/22 14:48:24 fab Exp $
 */

#include "globals.h"

/* public */
#include <intuition/intuition.h>
#include <workbench/workbench.h>

/* private */
#include "icon_internal.h"
#include "default.h"

extern const struct Image default_image;
extern const struct Image default_disk_image;
extern const struct Image default_drawer_image;
extern const struct Image default_kick_image;
extern const struct Image default_project_image;
extern const struct Image default_tool_image;

/*
 * Default structures. We use
 * the same as the original icon.library
 * for consistency (most of the time).
 */

/*
 * Default DrawerData
 */
static struct DrawerData defdrawerdata = {
	{ /* dd_NewWindow */
	    50,           /* LeftEdge */
		50,           /* TopEdge */
		400,          /* Width */
		100,          /* Height */
		0xff,         /* DetailPen */
		0xff,         /* BlockPen */
		NULL,         /* ICDMPFlags */
		WFLG_SIZEGADGET |
		WFLG_DRAGBAR |
		WFLG_DEPTHGADGET |
		WFLG_CLOSEGADGET |
		WFLG_SIZEBRIGHT |
		WFLG_SIZEBBOTTOM |
		WFLG_SIMPLE_REFRESH |
		WFLG_REPORTMOUSE |
		0x400000 | /* hm.. no clue what that is.. */
	    WFLG_WBENCHWINDOW,
		NULL,         /* FirstGadget */
		NULL,         /* CheckMark */
		NULL,         /* Title */
		NULL,         /* Screen */
		NULL,         /* BitMap */
		90,           /* MinWidth */
		40,           /* MinHeight */
		65535,        /* MaxWidth */
		65535,        /* MaxHeight */
		WBENCHSCREEN, /* Type */
	},
	0,            /* CurrentX */
	0,            /* CurrentY */
	NULL,         /* Flags */
	0             /* ViewModes */
};


/*
 * Default Disk
 */
struct KnownDiskObject defdisk = {
	{
	    WB_DISKMAGIC,
		WB_DISKVERSION,
		{ /* do_Gadget */
			NULL, /* NextGadget */
			0,    /* LeftEdge */
			0,    /* TopEdge */
			35,   /* Width */
			18,   /* Height */
			GFLG_GADGIMAGE | GFLG_GADGBACKFILL, /* Flags */
			GACT_RELVERIFY | GACT_IMMEDIATE,    /* Activation */
			GTYP_BOOLGADGET,                   /* GadgetType */
			(APTR)&default_disk_image,          /* GadgetRender */
			NULL, /* SelectRender */
			NULL, /* GadgetText */
			0,    /* MutualExclude */
			NULL, /* SpecialInfo */
			0,    /* GadgetID */
			NULL, /* UserData */
		},
		WBDISK,           /* do_Type */
		NULL,             /* do_DefaultTool */
		NULL,             /* do_ToolTypes */
		NO_ICON_POSITION, /* do_CurrentX */
		NO_ICON_POSITION, /* do_CurrentY */
		&defdrawerdata,   /* do_DrawerData */
		NULL,             /* do_ToolWindow */
		0                 /* do_StackSize */
	},
	NULL
};


/*
 * Default Drawer
 */
struct KnownDiskObject defdrawer = {
	{
	    WB_DISKMAGIC,
		WB_DISKVERSION,
		{ /* do_Gadget */
			NULL, /* NextGadget */
			0,    /* LeftEdge */
			0,    /* TopEdge */
			57,   /* Width */
			14,   /* Height */
			GFLG_GADGIMAGE | GFLG_GADGBACKFILL, /* Flags */
			GACT_RELVERIFY | GACT_IMMEDIATE,    /* Activation */
			GTYP_BOOLGADGET,                   /* GadgetType */
			(APTR)&default_drawer_image,        /* GadgetRender */
			NULL, /* SelectRender */
			NULL, /* GadgetText */
			0,    /* MutualExclude */
			NULL, /* SpecialInfo */
			0,    /* GadgetID */
			NULL, /* UserData */
		},
		WBDRAWER,         /* do_Type */
		NULL,             /* do_DefaultTool */
		NULL,             /* do_ToolTypes */
		NO_ICON_POSITION, /* do_CurrentX */
		NO_ICON_POSITION, /* do_CurrentY */
		&defdrawerdata,   /* do_DrawerData */
		NULL,             /* do_ToolWindow */
		0                 /* do_StackSize */
	},
	NULL
};


/*
 * Default Tool
 */
struct KnownDiskObject deftool = {
	{
	    WB_DISKMAGIC,
		WB_DISKVERSION,
		{ /* do_Gadget */
			NULL, /* NextGadget */
			0,    /* LeftEdge */
			0,    /* TopEdge */
			54,   /* Width */
			23,   /* Height */
			GFLG_GADGIMAGE | GFLG_GADGBACKFILL, /* Flags */
			GACT_RELVERIFY,                     /* Activation */
			GTYP_BOOLGADGET,                    /* GadgetType */
			(APTR)&default_tool_image,          /* GadgetRender */
			NULL, /* SelectRender */
			NULL, /* GadgetText */
			0,    /* MutualExclude */
			NULL, /* SpecialInfo */
			0,    /* GadgetID */
			NULL, /* UserData */
		},
		WBTOOL,           /* do_Type */
		NULL,             /* do_DefaultTool */
		NULL,             /* do_ToolTypes */
		NO_ICON_POSITION, /* do_CurrentX */
		NO_ICON_POSITION, /* do_CurrentY */
		NULL,             /* do_DrawerData */
		NULL,             /* do_ToolWindow */
		4096              /* do_StackSize */
	},
	NULL
};


/*
 * Default Project
 */
struct KnownDiskObject defproject = {
	{
	    WB_DISKMAGIC,
		WB_DISKVERSION,
		{ /* do_Gadget */
			NULL, /* NextGadget */
			0,    /* LeftEdge */
			0,    /* TopEdge */
			54,   /* Width */
			23,   /* Height */
			GFLG_GADGIMAGE | GFLG_GADGBACKFILL, /* Flags */
			GACT_RELVERIFY,                     /* Activation */
			GTYP_BOOLGADGET,                    /* GadgetType */
			(APTR)&default_project_image,       /* GadgetRender */
			NULL, /* SelectRender */
			NULL, /* GadgetText */
			0,    /* MutualExclude */
			NULL, /* SpecialInfo */
			0,    /* GadgetID */
			NULL, /* UserData */
		},
		WBPROJECT,         /* do_Type */
		NULL,             /* do_DefaultTool */
		NULL,             /* do_ToolTypes */
		NO_ICON_POSITION, /* do_CurrentX */
		NO_ICON_POSITION, /* do_CurrentY */
		NULL,             /* do_DrawerData */
		NULL,             /* do_ToolWindow */
		4096              /* do_StackSize */
	},
	NULL
};


/*
 * Default Trashcan
 */
struct KnownDiskObject deftrashcan = {
	{
	    WB_DISKMAGIC,
		WB_DISKVERSION,
		{ /* do_Gadget */
			NULL, /* NextGadget */
			0,    /* LeftEdge */
			0,    /* TopEdge */
			51,   /* Width */
			31,   /* Height */
			GFLG_GADGIMAGE | GFLG_GADGBACKFILL, /* Flags */
			GACT_RELVERIFY | GACT_IMMEDIATE,    /* Activation */
			GTYP_BOOLGADGET,                    /* GadgetType */
			(APTR)&default_image,               /* GadgetRender */
			NULL, /* SelectRender */
			NULL, /* GadgetText */
			0,    /* MutualExclude */
			NULL, /* SpecialInfo */
			0,    /* GadgetID */
			NULL, /* UserData */
		},
		WBGARBAGE,        /* do_Type */
		NULL,             /* do_DefaultTool */
		NULL,             /* do_ToolTypes */
		NO_ICON_POSITION, /* do_CurrentX */
		NO_ICON_POSITION, /* do_CurrentY */
		&defdrawerdata, /* do_DrawerData */
		NULL,               /* do_ToolWindow */
		0                   /* do_StackSize */
	},
	NULL
};


/*
 * Default Kick
 */
struct KnownDiskObject defkick = {
	{
	    WB_DISKMAGIC,
		WB_DISKVERSION,
		{ /* do_Gadget */
			NULL, /* NextGadget */
			0,    /* LeftEdge */
			0,    /* TopEdge */
			35,   /* Width */
			18,   /* Height */
			GFLG_GADGIMAGE | GFLG_GADGBACKFILL, /* Flags */
			GACT_RELVERIFY | GACT_IMMEDIATE,    /* Activation */
			GTYP_BOOLGADGET,                    /* GadgetType */
			(APTR)&default_kick_image,          /* GadgetRender */
			NULL, /* SelectRender */
			NULL, /* GadgetText */
			0,    /* MutualExclude */
			NULL, /* SpecialInfo */
			0,    /* GadgetID */
			NULL, /* UserData */
		},
		WBKICK,           /* do_Type */
		NULL,             /* do_DefaultTool */
		NULL,             /* do_ToolTypes */
		NO_ICON_POSITION, /* do_CurrentX */
		NO_ICON_POSITION, /* do_CurrentY */
		&defdrawerdata,   /* do_DrawerData */
		NULL,             /* do_ToolWindow */
		0                 /* do_StackSize */
	},
	NULL
};


/*
 * Default Device
 */
struct KnownDiskObject defdevice = {
	{
	    WB_DISKMAGIC,
		WB_DISKVERSION,
		{ /* do_Gadget */
			NULL, /* NextGadget */
			0,    /* LeftEdge */
			0,    /* TopEdge */
			35,   /* Width */
			18,   /* Height */
			GFLG_GADGIMAGE | GFLG_GADGBACKFILL, /* Flags */
			GACT_RELVERIFY | GACT_IMMEDIATE,    /* Activation */
			GTYP_BOOLGADGET,                    /* GadgetType */
			(APTR)&default_disk_image,          /* GadgetRender */
			NULL, /* SelectRender */
			NULL, /* GadgetText */
			0,    /* MutualExclude */
			NULL, /* SpecialInfo */
			0,    /* GadgetID */
			NULL, /* UserData */
		},
		WBDEVICE,         /* do_Type */
		NULL,             /* do_DefaultTool */
		NULL,             /* do_ToolTypes */
		NO_ICON_POSITION, /* do_CurrentX */
		NO_ICON_POSITION, /* do_CurrentY */
		&defdrawerdata,   /* do_DrawerData */
		NULL,             /* do_ToolWindow */
		0                 /* do_StackSize */
	},
	NULL
};



static const UWORD default_png_imagedata[] = {
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0060,0x00c1,0x8000,0xc000,0x01e0,0x0180,0x0001,0x8000,
	0x01e3,0xd9f3,0x3cfb,0xc000,0x0667,0xfbb6,0xcddb,0x0000,
	0x0666,0xdb36,0xcd9b,0x0000,0x0fcd,0xb66d,0xfb36,0x0000,
	0x186d,0xb66d,0x8336,0x0000,0x30db,0x6edb,0x366c,0x0000,
	0x30db,0x6f99,0xe666,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x03fc,0x783c,0x1f80,0x0000,
	0x03ff,0x7c3c,0x7fe0,0x0000,0x03ff,0x7c3c,0xfff0,0x0000,
	0x03cf,0xfe3c,0xf8f8,0x0000,0x03c7,0xff3d,0xf078,0x0000,
	0x03cf,0xff3d,0xe000,0x0000,0x03ff,0x7fbd,0xe000,0x0000,
	0x03ff,0x7fbd,0xe3fc,0x0000,0x03fc,0x7bfd,0xe3fc,0x0000,
	0x03c0,0x7bfd,0xe3fc,0x0000,0x03c0,0x79fd,0xf078,0x0000,
	0x03c0,0x78fc,0xf8f8,0x0000,0x03c0,0x78fc,0xfff0,0x0000,
	0x03c0,0x787c,0x7fe0,0x0000,0x03c0,0x783c,0x1f80,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xfc03,0x87c3,0xe07f,0xe000,0xfc00,0x83c3,0x801f,0xe000,
	0xfc00,0x83c3,0x000f,0xe000,0xfc30,0x01c3,0x0707,0xe000,
	0xfc38,0x00c2,0x0f87,0xe000,0xfc30,0x00c2,0x1fff,0xe000,
	0xfc00,0x8042,0x1fff,0xe000,0xfc00,0x8042,0x1c03,0xe000,
	0xfc03,0x8402,0x1c03,0xe000,0xfc3f,0x8402,0x1c03,0xe000,
	0xfc3f,0x8602,0x0f87,0xe000,0xfc3f,0x8703,0x0707,0xe000,
	0xfc3f,0x8703,0x000f,0xe000,0xfc3f,0x8783,0x801f,0xe000,
	0xfc3f,0x87c3,0xe07f,0xe000,0xffff,0xffff,0xffff,0xe000,
	0xffff,0xffff,0xffff,0xe000,0xffff,0xffff,0xffff,0xe000
};

const struct Image default_png_image = {
	0, 0, 51, 37, 2,    /* LeftEdge, TopEdge, Width, Height, Depth */
	(APTR)&default_png_imagedata,
	3, 0, NULL
};


static const UWORD default_imagedata[] = {
	0xffff,0xc000,0x8000,0x6000,0x8000,0x7000,0x8000,0x7800,
	0x8000,0x6c00,0x8000,0x6600,0x8000,0x6300,0x8000,0x7f80,
	0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,
	0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,
	0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,
	0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,
	0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,
	0xffff,0xff80,0xffff,0xff80,0x0000,0x0000,0x7fff,0x8000,
	0x7fff,0xa000,0x7fff,0xb000,0x7fff,0xb800,0x7fff,0xbc00,
	0x7fff,0xbe00,0x7fff,0x8000,0x7fff,0xff00,0x7fff,0xff00,
	0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,
	0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,
	0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,
	0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,
	0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,0x0000,0x0000
};

const struct Image default_image = {
	0, 0, 25, 30, 2,    /* LeftEdge, TopEdge, Width, Height, Depth */
	(APTR)&default_imagedata,
	3, 0, NULL
};


static const UWORD default_disk_imagedata[] = {
	0xffff,0xff80,0x9000,0x0580,0x9000,0x0580,0x9000,0x0580,
	0x9000,0x0580,0x9000,0x0580,0x9000,0x0580,0x9000,0x0580,
	0x9000,0x0580,0x9000,0x0580,0x9000,0x0580,0x9000,0x0580,
	0x9fff,0xfd80,0x8000,0x0180,0x8000,0x0180,0x87ff,0xe180,
	0x871f,0xe180,0x871f,0xe180,0x871f,0xe180,0x871f,0xe180,
	0x871f,0xe180,0xffff,0xff80,0xffff,0xff80,0x0000,0x0000,
	0x6fff,0xfb00,0x6fff,0xfb00,0x6fff,0xfb00,0x6fff,0xfb00,
	0x6fff,0xfb00,0x6fff,0xfb00,0x6fff,0xfb00,0x6fff,0xfb00,
	0x6fff,0xfb00,0x6fff,0xfb00,0x6fff,0xfb00,0x6000,0x0300,
	0x7fff,0xff00,0x7fff,0xff00,0x7800,0x1f00,0x78e0,0x1f00,
	0x78e0,0x1f00,0x78e0,0x1f00,0x78e0,0x1f00,0x78e0,0x1f00,
	0x78e0,0x1f00,0x0000,0x0000
};

const struct Image default_disk_image = {
	0, 0, 25, 23, 2,    /* LeftEdge, TopEdge, Width, Height, Depth */
	(APTR)&default_disk_imagedata,
	3, 0, NULL
};


static const UWORD default_drawer_imagedata[] = {
	0x0000,0x0000,0x0000,0x3000,0x0000,0xcc00,0x0003,0x0300,
	0x000c,0x0080,0x0030,0x0060,0x00c0,0x0018,0x0300,0x001c,
	0x0c00,0x0064,0x3000,0x0184,0x2c00,0x0604,0x2300,0x1804,
	0x20c0,0x6004,0x2031,0x8004,0x200e,0x0184,0x2008,0x060c,
	0x2008,0x1834,0x2008,0x00c4,0x2008,0x0304,0x2008,0x0c04,
	0x2008,0x3004,0x2008,0xc004,0x200b,0x0004,0x200c,0x0184,
	0x2008,0x0604,0x2008,0x180c,0x2008,0x0030,0x2008,0x00c0,
	0x2008,0x0300,0x1808,0x0c00,0x0608,0x3000,0x0188,0xc000,
	0x006b,0x0000,0x001c,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x3000,0x0000,0xfc00,0x0003,0xff00,0x000f,0xff80,
	0x003f,0xffe0,0x00ff,0xffe0,0x03ff,0xff98,0x0fff,0xfe78,
	0x13ff,0xf9f8,0x1cff,0xe7f8,0x1f3f,0x9ff8,0x1fce,0x7ff8,
	0x1ff1,0xfe78,0x1ff7,0xf9f0,0x1ff7,0xe7c8,0x1ff7,0xff38,
	0x1ff7,0xfcf8,0x1ff7,0xf3f8,0x1ff7,0xcff8,0x1ff7,0x3ff8,
	0x1ff4,0xfff8,0x1ff3,0xfe78,0x1ff7,0xf9f8,0x1ff7,0xe7f0,
	0x1ff7,0xffc0,0x1ff7,0xff00,0x1ff7,0xfc00,0x07f7,0xf000,
	0x01f7,0xc000,0x0077,0x0000,0x0014,0x0000,0x0000,0x0000
};

const struct Image default_drawer_image = {
	0, 0, 30, 34, 2,    /* LeftEdge, TopEdge, Width, Height, Depth */
	(APTR)&default_drawer_imagedata,
	3, 0, NULL
};


static const UWORD default_kick_imagedata[] = {
	0xffff,0xff80,0x9000,0x0580,0x9000,0x0580,0x9220,0x8580,
	0x9200,0x8580,0x92a6,0xa580,0x9328,0xc580,0x92a8,0xa580,
	0x92a6,0xa580,0x9000,0x0580,0x9000,0x0580,0x9000,0x0580,
	0x9fff,0xfd80,0x8000,0x0180,0x8000,0x0180,0x87ff,0xe180,
	0x871f,0xe180,0x871f,0xe180,0x871f,0xe180,0x871f,0xe180,
	0x871f,0xe180,0xffff,0xff80,0xffff,0xff80,0x0000,0x0000,
	0x6fff,0xfb00,0x6fff,0xfb00,0x6ddf,0x7b00,0x6dff,0x7b00,
	0x6d59,0x5b00,0x6cd7,0x3b00,0x6d57,0x5b00,0x6d59,0x5b00,
	0x6fff,0xfb00,0x6fff,0xfb00,0x6fff,0xfb00,0x6000,0x0300,
	0x7fff,0xff00,0x7fff,0xff00,0x7800,0x1f00,0x78e0,0x1f00,
	0x78e0,0x1f00,0x78e0,0x1f00,0x78e0,0x1f00,0x78e0,0x1f00,
	0x78e0,0x1f00,0x0000,0x0000
};

const struct Image default_kick_image = {
	0, 0, 25, 23, 2,    /* LeftEdge, TopEdge, Width, Height, Depth */
	(APTR)&default_kick_imagedata,
	3, 0, NULL
};


static const UWORD default_project_imagedata[] = {
	0xffff,0xc000,0x8000,0x6000,0x8000,0x7000,0x8000,0x7800,
	0x8000,0x6c00,0x8000,0x6600,0x8000,0x6300,0x8000,0x7f80,
	0x8000,0x0180,0x80fe,0x0180,0x830d,0x8180,0x8c18,0x6180,
	0x8830,0x2180,0x8c60,0x6180,0x83c1,0x8180,0x80fe,0x0180,
	0x8044,0x0180,0x8044,0x0180,0x8028,0x0180,0x8028,0x0180,
	0x8028,0x0180,0x8028,0x0180,0x8010,0x0180,0x8010,0x0180,
	0x8010,0x0180,0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,
	0xffff,0xff80,0xffff,0xff80,0x0000,0x0000,0x7fff,0x8000,
	0x7fff,0xa000,0x7fff,0xb000,0x7fff,0xb800,0x7fff,0xbc00,
	0x7fff,0xbe00,0x7fff,0x8000,0x7fff,0xff00,0x7f01,0xff00,
	0x7cf2,0x7f00,0x73e7,0x9f00,0x77cf,0xdf00,0x739f,0x9f00,
	0x7c3e,0x7f00,0x7f01,0xff00,0x7fbb,0xff00,0x7fbb,0xff00,
	0x7fd7,0xff00,0x7fd7,0xff00,0x7fd7,0xff00,0x7fd7,0xff00,
	0x7fef,0xff00,0x7fef,0xff00,0x7fef,0xff00,0x7fff,0xff00,
	0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,0x0000,0x0000
};

const struct Image default_project_image = {
	0, 0, 25, 30, 2,    /* LeftEdge, TopEdge, Width, Height, Depth */
	(APTR)&default_project_imagedata,
	3, 0, NULL
};


static const UWORD default_tool_imagedata[] = {
	0xffff,0xc000,0x8000,0x6000,0x8000,0x7000,0x8000,0x7800,
	0x8000,0x6c00,0x8000,0x6600,0x8000,0x6300,0x8000,0x7f80,
	0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,0x87fe,0x0180,
	0x87ff,0x0180,0x87ff,0xc180,0x87ff,0xf180,0x8038,0x0180,
	0x8038,0x0180,0x8038,0x0180,0x8038,0x0180,0x8038,0x0180,
	0x8038,0x0180,0x8038,0x0180,0x8038,0x0180,0x8038,0x0180,
	0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,0x8000,0x0180,
	0xffff,0xff80,0xffff,0xff80,0x0000,0x0000,0x7fff,0x8000,
	0x7fff,0xa000,0x7fff,0xb000,0x7fff,0xb800,0x7fff,0xbc00,
	0x7fff,0xbe00,0x7fff,0x8000,0x7fff,0xff00,0x7fff,0xff00,
	0x7fff,0xff00,0x7801,0xff00,0x7800,0xff00,0x7800,0x3f00,
	0x7800,0x0f00,0x7fc7,0xff00,0x7fc7,0xff00,0x7fc7,0xff00,
	0x7fc7,0xff00,0x7fc7,0xff00,0x7fc7,0xff00,0x7fc7,0xff00,
	0x7fc7,0xff00,0x7fc7,0xff00,0x7fff,0xff00,0x7fff,0xff00,
	0x7fff,0xff00,0x7fff,0xff00,0x7fff,0xff00,0x0000,0x0000
};

const struct Image default_tool_image = {
	0, 0, 25, 30, 2,    /* LeftEdge, TopEdge, Width, Height, Depth */
	(APTR)&default_tool_imagedata,
	3, 0, NULL
};
